@@ -4,11 +4,11 @@ use warnings;
 use Web::Scraper;
 use URI;
 
-sub url { 'http://www.willcom-inc.com/ja/service/contents_service/club_air_edge/for_phone/ip/' }
+sub url { 'http://www.willcom-inc.com/ja/service/contents_service/create/center_info/index.html' }
 
 sub scrape {
     scraper {
-        process '//td[@width="50%"]/font[@size="2"]', 'cidr[]', ['TEXT', sub {
+        process '//td[@align="center" and @bgcolor="white"]/font[@size="2"]', 'cidr[]', ['TEXT', sub {
                         m{^([0-9.]+)(/[0-9]+)};
                         +{ ip => $1, subnetmask => $2 };
                     }];
